require "responsive_image"

describe ResponsiveImage do

  context "with default configuration" do

    picture_element = ResponsiveImage::Helpers.create_picture("fishtank.jpg")

    it "should create a valid picture element" do
      expect(picture_element).to eq("<picture><!--[if IE 9]><video style='display: none;'><![endif]--><source srcset='/images/fishtank-mobile.jpg' media='(min-width: 480px)'><source srcset='/images/fishtank-mobile_2x.jpg' media='(min-width: 480px) and (min-device-pixel-ratio: 2.0)'><source srcset='/images/fishtank-tablet.jpg' media='(min-width: 768px)'><source srcset='/images/fishtank-tablet_2x.jpg' media='(min-width: 768px) and (min-device-pixel-ratio: 2.0)'><source srcset='/images/fishtank-desktop.jpg' media='(min-width: 1024px)'><source srcset='/images/fishtank-desktop_2x.jpg' media='(min-width: 1024px) and (min-device-pixel-ratio: 2.0)'><!--[if IE 9]></video><![endif]--><img srcset='/images/fishtank.jpg' class='' alt=''></picture>")
    end

  end

  context "with custom configuration" do

    it "should create a valid picture element" do
      ResponsiveImage.media_types = [{:filename_suffix => "iphone", :media_query => "(min-width: 320px)"}]

      picture_element = ResponsiveImage::Helpers.create_picture("fishtank.jpg")

      expect(picture_element).to eq("<picture><!--[if IE 9]><video style='display: none;'><![endif]--><source srcset='/images/fishtank-iphone.jpg' media='(min-width: 320px)'><!--[if IE 9]></video><![endif]--><img srcset='/images/fishtank.jpg' class='' alt=''></picture>")
    end

  end

  context "with custom html options" do

    it "should apply html options to the image element" do
      picture_element = ResponsiveImage::Helpers.create_picture("fishtank.jpg", :html => { :class => "awesome-image", :alt => "A really awesome image!" })

      expect(picture_element).to eq("<picture><!--[if IE 9]><video style='display: none;'><![endif]--><source srcset='/images/fishtank-iphone.jpg' media='(min-width: 320px)'><!--[if IE 9]></video><![endif]--><img srcset='/images/fishtank.jpg' class='awesome-image' alt='A really awesome image!'></picture>")
    end

  end

  context "with different host" do

    it "should create a valid picture element" do
      picture_element = ResponsiveImage::Helpers.create_picture("fishtank.jpg", :host => "http://placehold.it/")
      expect(picture_element).to eq("<picture><!--[if IE 9]><video style='display: none;'><![endif]--><source srcset='http://placehold.it/images/fishtank-iphone.jpg' media='(min-width: 320px)'><!--[if IE 9]></video><![endif]--><img srcset='http://placehold.it/images/fishtank.jpg' class='' alt=''></picture>")
    end

  end

end
